# Ultimate-Notion

> The ultimate Python library for Notion!


**This is a pre-alpha version! Don't use it!**

## Features

- in development
- ...

## License

Ultimate-Notion is distributed under the terms of the [MIT] license.

## Navigation

Documentation for specific `MAJOR.MINOR` versions can be chosen by using the dropdown on the top of every page. The `dev` version reflects changes that have not yet been released.

Also, desktop readers can use special keyboard shortcuts:

| Keys                                                         | Action                          |
|--------------------------------------------------------------|---------------------------------|
| <ul><li><kbd>,</kbd> (comma)</li><li><kbd>p</kbd></li></ul>  | Navigate to the "previous" page |
| <ul><li><kbd>.</kbd> (period)</li><li><kbd>n</kbd></li></ul> | Navigate to the "next" page     |
| <ul><li><kbd>/</kbd></li><li><kbd>s</kbd></li></ul>          | Display the search modal        |
